cat('\n In order to have a successful analysis of the data, the metadata package specific for the micro array used in the experiment should be installed.\n')
 
"GoTime" <-
function(ratios, selection, pmat, outputdir, metadata, ontology=c("MF","BP","CC"), timepoints=NULL){
# load necessary metadata package
	library(metadata, character.only=TRUE)
	
	cat("Number of significant ratios at each timepoint:\n")
	cat(apply(selection, 2, sum))
	cat("\n")
	
# calculate GO enrichment data for each of the three main GO categories
if ("MF" %in% ontology) {
	cat("constructing enrichment data for the Molecular Function ontology\n")
	restMF <- Go.enr(ratios, selection, "MF", metadata)
}
else {
	restMF <- NULL
}

if ("BP" %in% ontology) {
	cat("constructing enrichment data for the Biological Process ontology\n")
	restBP <- Go.enr(ratios, selection, "BP", metadata)
}
else {
	restBP <- NULL
}


if ("CC" %in% ontology) {
	cat("constructing enrichment data for the Cellular Component ontology\n")
	restCC <- Go.enr(ratios, selection, "CC", metadata)
}
else {
	restCC <- NULL
}

	if(is.null(timepoints)){
		timepoints <- 1:ncol(selection)
	}

# make directory structure for html pages of results
PrintIndex(outputdir, ontology, nrow(selection))
	
# make html for each class
	lpoints <- c(1:ncol(selection))
	m3 <- apply(selection, 2, sum)

if ("MF" %in% ontology) {
	tree.category(restMF, "MF", outputdir, ratios, metadata, timepoints, lpoints)
	tree.tpoint(restMF, "MF", lpoints, outputdir, timepoints, ratios, m3, metadata)
}

if ("BP" %in% ontology) {
	tree.category(restBP, "BP", outputdir, ratios, metadata, timepoints, lpoints)
	tree.tpoint(restBP, "BP", lpoints, outputdir, timepoints, ratios, m3, metadata)
}

if ("CC" %in% ontology) {
	tree.category(restCC, "CC", outputdir, ratios, metadata, timepoints, lpoints)
	tree.tpoint(restCC, "CC", lpoints, outputdir, timepoints, ratios, m3, metadata)
}
	
# make html for each individual gene
	tree.gene(restMF, restBP, restCC, outputdir, ratios, pmat, metadata, timepoints)
}

