\name{GoTime}
\alias{GoTime}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ function to visualise GO enrichment in time }
\description{
   Main function to call subroutines which calculate GO enrichment and Generate a html summary as output in a directory specified by the user.
}
\usage{
GoTime(ratios, selection, pmat, outputdir, metadata, ontology=c("MF","BP","CC"), timepoints = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ratios}{ \code{ratios} is a data frame containing the ratio values for the genes and timepoints, rows should be genes and columns should be timepoints, except for the first column which should contain the gene identifiers which can be used with the specific metadata package for the experiment }
  \item{selection}{ \code{selection} is a matrix which contains the values TRUE or FALSE, indicating wether a specific ratio is significant. Again each columns should be a timepoints and rows genes, but now the first column should be a timpoint as well and contain no gene identifiers}
  \item{pmat}{ \code{pmat} is a matrix of pvalues which were used to determine the significance of the ratios, columns are timepoints and rows are genes, the first column should be a timepoint }
  \item{outputdir}{ \code{outputdir} the name of the directory which will be physically created in the working directory , after running the function this directory will contain the results as html and jpeg files }
  \item{metadata}{ \code{metadata} should contain a character string which names the metadata package associated with the experiment }
  \item{ontology}{ \code{ontology} should contain character strings of the desired ontologies to be investigated by the user }
  \item{timepoints}{ \code{timepoints} is an optional vector which contains the real number of timeunits on for each timepoint }
}
\details{
   The fuction will create html output which can be viewed with a standard browser. The best starting point for surfing through the data would be the file start.html in the directory which is specified and named by the user 
}
\value{
  No real value is returned by the function, html and png files are generated as output
}

\author{ J. de Haan }

\seealso{ \code{\link{Go.enr}}, \code{\link{tree.category}},  \code{\link{tree.tpoint}}, \code{\link{tree.gene}}}
\examples{
#load fruitfly time course data from timecourse package
data(fruitfly)
design <- rep(1:12, 3)

#calculate mean expression per gene per timepoint
mn.pergene <- matrix(0, ncol=12, nrow=2000)
for(timepoint in 1:12){
	mn.pergene[, timepoint] <- apply(fruitfly[,(design \%in\% timepoint)], 1,mean)
}

#calculate ratio with first timepoint 
mn.first.timepoint <- mn.pergene[,1]
other.timepoints <- mn.pergene[,2:12]
ratio.pergene <- apply(other.timepoints, 2, function(other.timepoints) other.timepoints/mn.first.timepoint)

#calculate significance for ratio with for instance simple t-test
sign.diff <- matrix(0, ncol=11, nrow=2000)
first.timepoint2 <- fruitfly[, (design \%in\% 1)]
for (r in 1:11){
	reps.timepoint <- cbind(first.timepoint2, fruitfly[,(design \%in\% (r+1))])
	sign.diff[,r] <- apply(reps.timepoint, 1, function(reps.timepoint) t.test(reps.timepoint[1:3], reps.timepoint[4:6])$p.value)
}

#generate GO enrichment in time
ratios <- data.frame(rownames(fruitfly), ratio.pergene)
selection <- sign.diff < 0.01

# example with reduced set of genes
set.seed(1)
shortlist <- sample(1:2000, 300)
GoTime(ratios[shortlist,1:6], selection[shortlist,1:5], sign.diff[shortlist,1:5], "dros", "drosgenome1", ontology="BP")

# example with the whole set of genes
\dontrun{ GoTime(ratios, selection, sign.diff, "dros", "drosgenome1", ontology="BP")}

browseURL(paste(getwd(),"dros", "start.html", sep="/"))
}
\keyword{ ts }