\name{GoTime-package}
\alias{GoTime-package}
%\alias{GoTime}
\docType{package}
\title{ Visualization of GO enrichment for time series microarray data }
\description{ Data from microarray experiments can be summarised in a GO time profile. Ratio's should be used as input. HTML output is generated in which the profiles are displayed for each significantly enriched GO term.
}
\details{
\tabular{ll}{
Package: \tab GoTime\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2006-02-10\cr
License: \tab Free re-distribution for non-commercial purpose.\cr
}
}
\author{
Jorn de Haan
Maintainer: <J.dehaan@science.ru.nl>
}

\keyword{ ts } 

\seealso{ \code{\link{GoTime}},  \code{\link{Go.enr}}, \code{\link{tree.category}},  \code{\link{tree.tpoint}}, \code{\link{tree.gene}}}
\examples{

#load fruitfly time course data from timecourse package
data(fruitfly)
design <- rep(1:12, 3)

#calculate mean expression per gene per timepoint
mn.pergene <- matrix(0, ncol=12, nrow=2000)
for(timepoint in 1:12){
	mn.pergene[, timepoint] <- apply(fruitfly[,(design \%in\% timepoint)], 1,mean)
}

#calculate ratio with first timepoint 
mn.first.timepoint <- mn.pergene[,1]
other.timepoints <- mn.pergene[,2:12]
ratio.pergene <- apply(other.timepoints, 2, function(other.timepoints) other.timepoints/mn.first.timepoint)

#calculate significance for ratio with for instance simple t-test
sign.diff <- matrix(0, ncol=11, nrow=2000)
first.timepoint2 <- fruitfly[, (design \%in\% 1)]
for (r in 1:11){
	reps.timepoint <- cbind(first.timepoint2, fruitfly[,(design \%in\% (r+1))])
	sign.diff[,r] <- apply(reps.timepoint, 1, function(reps.timepoint) t.test(reps.timepoint[1:3], reps.timepoint[4:6])$p.value)
}

#generate GO enrichment in time
Int <- data.frame(rownames(fruitfly), ratio.pergene)
selmatrix <- sign.diff < 0.01
GoTime(Int, selmatrix, sign.diff, "dros", "drosgenome1",)
}
